//Source file: ChargingSession.java
//Date: December 2005
//Charging Interfaces and Data Types for 3GPP TS 29.198-12 V5.9.0

package org.csapi.jr.se.cs;

/**
 * This interface represents a ChargingSession.<BR>
 *
 */
public interface ChargingSession extends org.csapi.jr.se.Service {

    /**
     * Adds a ChargingSessionListener which is interested in events generated by the ChargingSession.
     *
     * @param  chargingSessionListener  A reference to the ChargingSessionListener which is to be added as
     *         a listener.
     */
    void addChargingSessionListener(org.csapi.jr.se.cs.ChargingSessionListener chargingSessionListener);

    /**
     * Removes a ChargingSessionListener which is no longer interested in events generated by the ChargingSession.
     *
     * @param  chargingSessionListener  A reference to the ChargingSessionListener which is to be removed as
     *         a listener.
     */
    void removeChargingSessionListener(org.csapi.jr.se.cs.ChargingSessionListener chargingSessionListener);

    /**
     * Returns a reference to the ChargingManager responsible for creation of the ChargingSession.
     *
     * @return  A reference to the ChargingManager responsible for creation of the ChargingSession.
     */
    org.csapi.jr.se.cs.ChargingManager getChargingManager();

    /**
     * Invokes the creditAmountReq() method on the Parlay Gateway.
     */
    void creditAmountReq(
           org.csapi.jr.se.cs.ApplicationDescription applicationDescription,
           org.csapi.jr.se.cs.ChargingPrice amount,
           boolean                         closeReservation)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.InvalidAmountException,
       org.csapi.jr.se.InvalidCurrencyException,
       org.csapi.jr.se.cs.InvalidRequestNumberException;

    /**
     * Invokes the creditUnitReq() method on the Parlay Gateway.
     */
    void creditUnitReq(
           org.csapi.jr.se.cs.ApplicationDescription applicationDescription,
           org.csapi.jr.se.cs.Volume[] volumes,
           boolean                         closeReservation)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.cs.InvalidVolumeException,
       org.csapi.jr.se.cs.InvalidRequestNumberException;

    /**
     * Invokes the debitAmountReq() method on the Parlay Gateway.
     */
    void debitAmountReq(
           org.csapi.jr.se.cs.ApplicationDescription applicationDescription,
           org.csapi.jr.se.cs.ChargingPrice amount,
           boolean                         closeReservation)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.InvalidAmountException,
       org.csapi.jr.se.InvalidCurrencyException,
       org.csapi.jr.se.cs.InvalidRequestNumberException;

    /**
     * Invokes the debitUnitReq() method on the Parlay Gateway.
     */
    void debitUnitReq(
           org.csapi.jr.se.cs.ApplicationDescription applicationDescription,
           org.csapi.jr.se.cs.Volume[] volumes,
           boolean                         closeReservation)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.cs.InvalidVolumeException,
       org.csapi.jr.se.cs.InvalidRequestNumberException;

    /**
     * Invokes the directCreditAmountReq() method on the Parlay Gateway.
     */
    void directCreditAmountReq(
           org.csapi.jr.se.cs.ApplicationDescription applicationDescription,
           org.csapi.jr.se.cs.ChargingParameter[] chargingParameters,
           org.csapi.jr.se.cs.ChargingPrice amount)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.InvalidAmountException,
       org.csapi.jr.se.InvalidCurrencyException,
       org.csapi.jr.se.cs.InvalidRequestNumberException;

    /**
     * Invokes the directCreditUnitReq() method on the Parlay Gateway.
     */
    void directCreditUnitReq(
           org.csapi.jr.se.cs.ApplicationDescription applicationDescription,
           org.csapi.jr.se.cs.ChargingParameter[] chargingParameters,
           org.csapi.jr.se.cs.Volume[] volumes)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.cs.InvalidVolumeException,
       org.csapi.jr.se.cs.InvalidRequestNumberException;

    /**
     * Invokes the directDebitAmountReq() method on the Parlay Gateway.
     */
    void directDebitAmountReq(
           org.csapi.jr.se.cs.ApplicationDescription applicationDescription,
           org.csapi.jr.se.cs.ChargingParameter[] chargingParameters,
           org.csapi.jr.se.cs.ChargingPrice amount)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.InvalidAmountException,
       org.csapi.jr.se.InvalidCurrencyException,
       org.csapi.jr.se.cs.InvalidRequestNumberException;

    /**
     * Invokes the directDebitUnitReq() method on the Parlay Gateway.
     */
    void directDebitUnitReq(
           org.csapi.jr.se.cs.ApplicationDescription applicationDescription,
           org.csapi.jr.se.cs.ChargingParameter[] chargingParameters,
           org.csapi.jr.se.cs.Volume[] volumes)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.cs.InvalidVolumeException,
       org.csapi.jr.se.cs.InvalidRequestNumberException;

    /**
     * Invokes the extendLifeTimeReq() method on the Parlay Gateway.
     */
    void extendLifeTimeReq()
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException;

    /**
     * Invokes the getAmountLeft() method on the Parlay Gateway.
     */
    org.csapi.jr.se.cs.ChargingPrice getAmountLeft()
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException;

    /**
     * Invokes the getLifeTimeLeft() method on the Parlay Gateway.
     */
    int getLifeTimeLeft()
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException;

    /**
     * Invokes the getUnitLeft() method on the Parlay Gateway.
     */
    org.csapi.jr.se.cs.Volume[] getUnitLeft()
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException;

    /**
     * Invokes the rateReq() method on the Parlay Gateway.
     */
    void rateReq(
           org.csapi.jr.se.cs.ChargingParameter[] chargingParameters)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException;

    /**
     * Invokes the release() method on the Parlay Gateway.
     */
    void release()
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.cs.InvalidRequestNumberException;

    /**
     * Invokes the reserveAmountReq() method on the Parlay Gateway.
     */
    void reserveAmountReq(
           org.csapi.jr.se.cs.ApplicationDescription applicationDescription,
           org.csapi.jr.se.cs.ChargingParameter[] chargingParameters,
           org.csapi.jr.se.cs.ChargingPrice preferredAmount,
           org.csapi.jr.se.cs.ChargingPrice minimumAmount)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.InvalidAmountException,
       org.csapi.jr.se.InvalidCurrencyException,
       org.csapi.jr.se.cs.InvalidRequestNumberException;

    /**
     * Invokes the reserveUnitReq() method on the Parlay Gateway.
     */
    void reserveUnitReq(
           org.csapi.jr.se.cs.ApplicationDescription applicationDescription,
           org.csapi.jr.se.cs.ChargingParameter[] chargingParameters,
           org.csapi.jr.se.cs.Volume[] volumes)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.cs.InvalidVolumeException,
       org.csapi.jr.se.cs.InvalidRequestNumberException;

}
