//Source file: SessionEndedCause.java
//Date: December 2005
//Charging Interfaces and Data Types for 3GPP TS 29.198-12 V5.9.0

package org.csapi.jr.se.cs;

/**
 * Defines the reason for which a charging session is released.
 *
 */
public final class SessionEndedCause implements java.io.Serializable {

    private int _value;
    private static int _size = 2;
    private static SessionEndedCause[] _array = new SessionEndedCause[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private SessionEndedCause(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * The reason of release is not known, because no info was received from the network.
     */
    public static final int _CHS_CAUSE_UNDEFINED =  0;

    /**
     * The reason of release is not known, because no info was received from the network.
     */
    public static final SessionEndedCause CHS_CAUSE_UNDEFINED = new SessionEndedCause(_CHS_CAUSE_UNDEFINED);

    /**
     * The session lifetime has expired.
     */
    public static final int _CHS_CAUSE_TIMER_EXPIRED =  1;

    /**
     * The session lifetime has expired.
     */
    public static final SessionEndedCause CHS_CAUSE_TIMER_EXPIRED = new SessionEndedCause(_CHS_CAUSE_TIMER_EXPIRED);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved SessionEndedCause object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the SessionEndedCause object
     */
    public String getValueText() {
        switch (_value) {
            case _CHS_CAUSE_UNDEFINED:
                return "CHS_CAUSE_UNDEFINED";
            case _CHS_CAUSE_TIMER_EXPIRED:
                return "CHS_CAUSE_TIMER_EXPIRED";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 1
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static SessionEndedCause getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof SessionEndedCause)) {
            return false;
        }
        SessionEndedCause sessionEndedCause = (SessionEndedCause) o; 
        if(!(this.getValue() == sessionEndedCause.getValue())) {
            return false;
        }
        if (this.hashCode() != sessionEndedCause.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // SessionEndedCause

